@@ -10,23 +10,22 @@ class ParalleLauncher():
 
 
     def __init__(self,  db_path, meta_stationarize=[True], meta_normalize=[True], meta_advance_features=[False], meta_advance_signals=[False], meta_history=[False], meta_layers=[[2048,1024,512,256,128,64,32]], convolutions=[0], activations=['relu'], meta_n=[126], meta_seeds=[0], epochss=[1], ss=[21], meta_n_past_features=[21], utilities=['f_drawdown']):
-        print('Epochs ' + str(epochss))
-        print('Seed ' + str(meta_seeds))
-        print('Training period size ' + str(meta_n))
-        print('Neural net layout ' + str(meta_layers))
-        print('Stationarize ' + str(meta_stationarize))
-        print('Normalize ' + str(meta_normalize))
-        print('Advanced ' + str(meta_advance_features))
-        print('Signals ' + str(meta_advance_signals))
-        print('History ' + str(meta_history))
-        print('Normalized ' + str(meta_normalize))
-        print('Rebalancing ' + str(ss))
-        print('Activation ' + str(activations))
-        print('Convolution' + str(convolutions))
-        print('Utility' + str(utilities))
-        print('n past features ' + str(meta_n_past_features))
-        print('Rebalancing ' + str(ss))
-
+        # print('Epochs ' + str(epochss))
+        # print('Seed ' + str(meta_seeds))
+        # print('Training period size ' + str(meta_n))
+        # print('Neural net layout ' + str(meta_layers))
+        # print('Stationarize ' + str(meta_stationarize))
+        # print('Normalize ' + str(meta_normalize))
+        # print('Advanced ' + str(meta_advance_features))
+        # print('Signals ' + str(meta_advance_signals))
+        # print('History ' + str(meta_history))
+        # print('Normalized ' + str(meta_normalize))
+        # print('Rebalancing ' + str(ss))
+        # print('Activation ' + str(activations))
+        # print('Convolution' + str(convolutions))
+        # print('Utility' + str(utilities))
+        # print('n past features ' + str(meta_n_past_features))
+        # print('Rebalancing ' + str(ss))
         self.args = []
         self.counter = 1
         for utility in utilities:
